 /***************************************************************************
 *
 * Copyright (C) 2008,2009  SMSC
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ***************************************************************************
 * File: smsc_debug.h
 ***************************************************************************
 * History:
 *
 * 10/10/2008, Vlad Lyalikov Version 3.00
 *  
 */
#ifndef smsc_debug_h_defined

extern ulong debug_mode;
#ifdef USE_DEBUG
//select debug modes
#define USE_WARNING
#define USE_TRACE
#define USE_ASSERT
#endif //USE_DEBUG


#define DBG_TRACE       (1 << 0)
#define DBG_WARNING     (1 << 1)
#define DBG_ETH_GPIO    (1 << 2)
#define DBG_SYS_GPIO    (1 << 3)

#define DBG_INIT        (0x80000000UL)
#define DBG_CLOSE       (0x40000000UL)
#define DBG_ISR         (0x20000000UL)
#define DBG_PWR         (0x10000000UL)
#define DBG_IOCTL       (0x08000000UL)
#define DBG_LINK        (0x04000000UL)
#define DBG_RX          (0x02000000UL)
#define DBG_TX          (0x01000000UL)
#define DBG_MCAST       (0x00800000UL)

/*******************************************************
* Macro: SMSC_TRACE
* Description: 
*    This macro is used like printf. 
*    It can be used anywhere you want to display information
*    For any release version it should not be left in 
*      performance sensitive Tx and Rx code paths.
*    To use this macro define USE_TRACE and set bit 0 of debug_mode
*******************************************************/
#ifdef USING_LINT
extern void SMSC_TRACE(unsigned long dbgBit, const char * a, ...);
#else //not USING_LINT
#ifdef USE_TRACE
//extern ulong debug_mode;
#ifndef USE_WARNING
#define USE_WARNING
#endif
#   define SMSC_TRACE(dbgBit,msg,args...)   \
    if(debug_mode&dbgBit) {                 \
        printk("SMSC_ETH: " msg "\n", ## args); \
    }
#else
#   define SMSC_TRACE(dbgBit,msg,args...)
#endif
#endif //end of not USING_LINT

/*******************************************************
* Macro: SMSC_WARNING
* Description: 
*    This macro is used like printf. 
*    It can be used anywhere you want to display warning information
*    For any release version it should not be left in 
*      performance sensitive Tx and Rx code paths.
*    To use this macro define USE_TRACE or 
*      USE_WARNING and set bit 1 of debug_mode
*******************************************************/


#ifdef USING_LINT
extern void SMSC_WARNING(const char * a, ...);
#else //not USING_LINT
#ifdef USE_WARNING
//extern ulong debug_mode;
#ifndef USE_ASSERT
#define USE_ASSERT
#endif
#   define SMSC_WARNING(msg, args...)               \
    if(debug_mode&DBG_WARNING) {                    \
        printk("SMSC_ETH_WARNING: ");\
        printk(__FUNCTION__);\
        printk(": " msg "\n",## args);\
    }
#else
#   define SMSC_WARNING(msg, args...)
#endif
#endif //end of not USING_LINT



/*******************************************************
* Macro: SMSC_ASSERT
* Description: 
*    This macro is used to test assumptions made when coding. 
*    It can be used anywhere, but is intended only for situations
*      where a failure is fatal. 
*    If code execution where allowed to continue it is assumed that 
*      only further unrecoverable errors would occur and so this macro
*      includes an infinite loop to prevent further corruption.
*    Assertions are only intended for use during developement to 
*      insure consistency of logic through out the driver.
*    A driver should not be released if assertion failures are 
*      still occuring.
*    To use this macro define USE_TRACE or USE_WARNING or
*      USE_ASSERT
*******************************************************/
#ifdef USING_LINT
extern void SMSC_ASSERT(ulong condition);
#else //not USING_LINT
#ifdef USE_ASSERT
    #define SMSC_ASSERT(condition)                                                  \
    if(!(condition)) {                                                              \
        printk("SMSC_ETH_ASSERTION_FAILURE: \n");\
        printk("    Condition = " #condition "\n");\
        printk("    Function  = ");printk(__FUNCTION__);printk("\n");\
        printk("    File      = " __FILE__ "\n");\
        printk("    Line      = %d\n",__LINE__);    \
        while(1);\
    }
#else 
#   define SMSC_ASSERT(condition)
#endif
#endif //end of not USING_LINT


//extern ulong debug_mode;
extern ulong gpo_mask;
#define GP_0    (0x01UL)
#define GP_1    (0x02UL)
#define GP_2    (0x04UL)
#define GP_3    (0x08UL)
#define GP_4    (0x10UL)
#define GP_5    (0x20UL)
#define GP_6    (0x40UL)
#define GP_7    (0x80UL)
#define GP_OFF  (0x00UL)
#define GP_ISR      GP_0
#define GP_TXT      GP_1    //Tx completion Tasklet
#define GP_TX1      GP_2    //Tx Send function
#define GP_TX2      GP_3    //Tx Complete function
#define GP_RXT      GP_4    //Rx Tasklet/NAPI poller
#define GP_RX1      GP_5    //Rx transfer packets from DMA ring to OS
#define GP_RX2      GP_6    //Rx prepare DMA ring for new packets
#define GP_GPT      GP_OFF  //General purpose timer
#define GP_FC       GP_OFF  //Flow control active
#define GP_BP       GP_OFF  //Burst period active
#define GP_STP      GP_OFF  //stop function
#define GP_SPD      GP_OFF  //Suspend Request
#define GP_RSM      GP_OFF  //Resume Request

#define SET_SYS_GPO(gpoBit)
#define CLEAR_SYS_GPO(gpoBit)
#define PULSE_SYS_GPO(gpoBit)
#define SET_APP_GPO(gpoBit)
#define CLEAR_APP_GPO(gpoBit)
#define PULSE_APP_GPO(gpoBit)
#define INIT_APP_GPO(gpoBit)


#define smsc_debug_h_defined
#endif

